@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '2.003000';
+$MetaCPAN::Client::VERSION = '2.004000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_arrayref is_hashref >;
@@ -296,8 +296,8 @@ sub _reverse_deps {
                 query  => { match_all => {} },
                 filter => {
                     and => [
-                        { term => { 'release.status' => 'latest' } },
-                        { term => { 'authorized'     => \1       } },
+                        { term => { 'status'     => 'latest' } },
+                        { term => { 'authorized' => 1        } },
                     ]
                 },
             }
@@ -371,7 +371,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 2.003000
+version 2.004000
 
 =head1 SYNOPSIS
 
