@@ -2,10 +2,11 @@ use strict;
 use warnings;
 package MetaCPAN::Client::ResultSet;
 # ABSTRACT: A Result Set
-$MetaCPAN::Client::ResultSet::VERSION = '2.003000';
+$MetaCPAN::Client::ResultSet::VERSION = '2.004000';
 use Moo;
 use Carp;
-use Ref::Util qw< is_arrayref >;
+
+use MetaCPAN::Client::Types qw< ArrayRef >;
 
 has type => (
     is       => 'ro',
@@ -22,8 +23,8 @@ has scroller => (
     is        => 'ro',
     isa       => sub {
         use Safe::Isa;
-        $_[0]->$_isa('Search::Elasticsearch::Scroll')
-            or croak 'scroller must be an Search::Elasticsearch::Scroll object';
+        $_[0]->$_isa('MetaCPAN::Client::Scroll')
+            or croak 'scroller must be an MetaCPAN::Client::Scroll object';
     },
     predicate => 'has_scroller',
 );
@@ -31,10 +32,7 @@ has scroller => (
 # in case we're returning from a fetch
 has items => (
     is  => 'ro',
-    isa => sub {
-        is_arrayref($_[0])
-            or croak 'items must be an array ref';
-    },
+    isa => ArrayRef,
 );
 
 has total => (
@@ -91,7 +89,7 @@ MetaCPAN::Client::ResultSet - A Result Set
 
 =head1 VERSION
 
-version 2.003000
+version 2.004000
 
 =head1 DESCRIPTION
 
@@ -103,7 +101,7 @@ provides easy access to the scroller and aggregations.
 
 =head2 scroller
 
-An L<Search::Elasticsearch::Scroll> object.
+An L<MetaCPAN::Client::Scroll> object.
 
 =head2 items
 
